Index: src/services/ActivityPubService.js
===================================================================
--- src/services/ActivityPubService.js	(revision 09fc5fb298f25f61bef8fa385fdf73f1c2c7781f)
+++ src/services/ActivityPubService.js	(revision 3bbf73d1fa44d3393eeff82f89790687762e1983)
@@ -4210,12 +4210,12 @@
 // visibility 'direct'. Een publiek antwoord is geen gesprek en hoort niet als
 // gezicht in de hemel.
-const GESPREK_UNIE = `
+const CONVERSATION_UNION = `
   SELECT m.actor_uri AS other, COALESCE(m.published, m.created_at) AS stamp,
-         'in' AS richting, m.object_uri AS ref
+         'in' AS direction, m.object_uri AS ref
     FROM ap_mentions m
    WHERE m.slug = @slug AND m.actor_uri IS NOT NULL AND m.actor_uri <> ''
   UNION ALL
   SELECT j.value AS other, o.created_at AS stamp,
-         'uit' AS richting, o.id AS ref
+         'out' AS direction, o.id AS ref
     FROM ap_outbox o
     JOIN json_each(COALESCE(NULLIF(o.to_actors, ''), json_array(o.to_actor))) j
@@ -4233,7 +4233,7 @@
   try {
     return db.prepare(`
-      SELECT other, stamp, richting, ref FROM (
+      SELECT other, stamp, direction, ref FROM (
         SELECT *, ROW_NUMBER() OVER (PARTITION BY other ORDER BY stamp DESC, ref DESC) AS rn
-          FROM (${GESPREK_UNIE})
+          FROM (${CONVERSATION_UNION})
       ) WHERE rn = 1
       ORDER BY stamp DESC, ref DESC`).all({ slug });
@@ -4260,27 +4260,27 @@
  * ontbreekt alleen iets in het midden.
  */
-const cursorVan = (r) => (r ? `${r.stamp}|${r.ref}` : null);
+const cursorOf = (r) => (r ? `${r.stamp}|${r.ref}` : null);
 
 export function conversationHistory(slug, other, { before = null, limit = 60 } = {}) {
   try {
     const n = Math.min(Math.max(parseInt(limit, 10) || 60, 1), 200);
-    const knip = String(before || '').indexOf('|');
-    const bStamp = before && knip > 0 ? String(before).slice(0, knip) : null;
-    const bRef = before && knip > 0 ? String(before).slice(knip + 1) : null;
-    const rijen = db.prepare(`
-      SELECT other, stamp, richting, ref FROM (${GESPREK_UNIE})
+    const sep = String(before || '').indexOf('|');
+    const bStamp = before && sep > 0 ? String(before).slice(0, sep) : null;
+    const bRef = before && sep > 0 ? String(before).slice(sep + 1) : null;
+    const rows = db.prepare(`
+      SELECT other, stamp, direction, ref FROM (${CONVERSATION_UNION})
        WHERE other = @other
          AND (@bStamp IS NULL OR stamp < @bStamp OR (stamp = @bStamp AND ref < @bRef))
        ORDER BY stamp DESC, ref DESC LIMIT @n`).all({ slug, other, bStamp, bRef, n: n + 1 });
-    const meer = rijen.length > n;
-    const uit = meer ? rijen.slice(0, n) : rijen;
-    return { rijen: uit, meer, oudste: cursorVan(uit[uit.length - 1]) };
-  } catch { return { rijen: [], meer: false, oudste: null }; }
+    const more = rows.length > n;
+    const page = more ? rows.slice(0, n) : rows;
+    return { rows: page, more, oldest: cursorOf(page[page.length - 1]) };
+  } catch { return { rows: [], more: false, oldest: null }; }
 }
 
 // De kolommen die een bericht tot kaart maken. Een constante, want de
 // gesprekslezing haalt dezelfde rijen op: twee lijsten die uiteenlopen leveren
 // een kaart die op de ene plek een plaatje heeft en op de andere niet.
-const BERICHT_KOLOMMEN = `
+const MESSAGE_COLUMNS = `
       m.object_uri, m.note_url, m.actor_uri, m.actor_name, m.actor_handle, m.actor_icon, m.actor_url,
       m.content, m.published, m.created_at, m.wave, m.help_request,
@@ -4293,5 +4293,5 @@
   try {
     const gaten = lijst.map(() => '?').join(',');
-    return db.prepare(`SELECT ${BERICHT_KOLOMMEN} FROM ap_mentions m
+    return db.prepare(`SELECT ${MESSAGE_COLUMNS} FROM ap_mentions m
                         WHERE m.slug = ? AND m.object_uri IN (${gaten})`).all(slug, ...lijst);
   } catch { return []; }
@@ -4301,5 +4301,5 @@
   try {
     return db.prepare(`
-      SELECT ${BERICHT_KOLOMMEN}
+      SELECT ${MESSAGE_COLUMNS}
       FROM ap_mentions m
       WHERE m.slug = ?
@@ -4260,27 +4260,27 @@
 
 // De kolommen die een bericht tot kaart maken. Een constante, want de
-// gesprekslezing haalt dezelfde rijen op: twee lijsten die uiteenlopen leveren
+// gesprekslezing haalt dezelfde rows op: twee lijsten die uiteenlopen leveren
 // een kaart die op de ene plek een plaatje heeft en op de andere niet.
